@@ -11,48 +11,92 @@ setMethod(
   definition = function(object) {
     switch (
       tolower(object),
-      bp = .BP(),
-      b2k = .b2k(),
-      bc = .BC(),
-      bce = .BCE(),
-      ad = .AD(),
-      ce = .CE(),
-      julian = .JulianCalendar(),
-      stop(sprintf("Unknown calendar: %s", object), call. = FALSE)
+      bp = BP(),
+      b2k = b2k(),
+      bc = BC(),
+      bce = BCE(),
+      ad = AD(),
+      ce = CE(),
+      julian = J(),
+      stop(sprintf(tr_("Unknown calendar: %s"), object), call. = FALSE)
     )
   }
 )
 
 #' @export
 #' @rdname gregorian
-BP <- function(...) calendar("BP")
+BP <- function(...) {
+  .GregorianCalendar(
+    label = tr_("BP"),
+    name = tr_("Before Present"),
+    epoch = 1950,
+    direction = -1L
+  )
+}
 
 #' @export
 #' @rdname gregorian
-b2k <- function(...) calendar("b2k")
+b2k <- function(...) {
+  .GregorianCalendar(
+    label = tr_("b2k"),
+    name = tr_("Before 2000"),
+    epoch = 2000,
+    direction = -1L
+  )
+}
 
 #' @export
 #' @rdname gregorian
-BC <- function(...) calendar("BC")
+BC <- function(...) {
+  .GregorianCalendar(
+    label = tr_("BC"),
+    name = tr_("Before Christ"),
+    direction = -1L
+  )
+}
 
 #' @export
 #' @rdname gregorian
-BCE <- function(...) calendar("BCE")
+BCE <- function(...) {
+  .GregorianCalendar(
+    label = tr_("BCE"),
+    name = tr_("Before Common Era"),
+    direction = -1L
+  )
+}
 
 #' @export
 #' @rdname gregorian
-AD <- function(...) calendar("AD")
+AD <- function(...) {
+  .GregorianCalendar(
+    label = tr_("AD"),
+    name = tr_("Anno Domini")
+  )
+}
 
 #' @export
 #' @rdname gregorian
-CE <- function(...) calendar("CE")
+CE <- function(...) {
+  .GregorianCalendar(
+    label = tr_("CE"),
+    name = tr_("Common Era")
+  )
+}
 
 #' @export
 #' @rdname julian
-J <- function(...) calendar("julian")
+J <- function(...) {
+  .JulianCalendar(
+    label = "",
+    name = ""
+  )
+}
 
 # Mutators =====================================================================
-calendar_year <- function(object) object@year
+calendar_year <- function(object) {
+  if (is.null(object)) return(NULL)
+  object@year
+}
 
 ## Getters ---------------------------------------------------------------------
 #' @export
@@ -80,9 +124,9 @@ setMethod(
   f = "calendar_unit",
   signature = "TimeScale",
   definition = function(object) {
-    if (is_gregorian(object)) return("Gregorian")
-    if (is_julian(object)) return("Julian")
-    return("Undefined")
+    if (is_gregorian(object)) return(tr_("Gregorian years"))
+    if (is_julian(object)) return(tr_("Julian years"))
+    return(tr_("Undefined"))
   }
 )
 
